@@ -6,7 +6,7 @@ whenever it sees a test outcome that includes exc_info.
 
 It fires :func:`beforeInteraction` before launching pdb and
 :func:`afterInteraction` after. Other plugins may implement
-:func:`beforeInteraction` to return False and set event.handled to
+:func:`beforeInteraction` to return ``False`` and set ``event.handled`` to
 prevent this plugin from launching pdb.
 
 """
@@ -15,12 +15,12 @@ import pdb
 
 from nose2 import events
 
-
 __unittest = True
 log = logging.getLogger(__name__)
 
 
 class Debugger(events.Plugin):
+
     """Enter pdb on test error or failure
 
     .. attribute :: pdb
@@ -29,13 +29,14 @@ class Debugger(events.Plugin):
        is aliased as a class attribute.
 
     """
-    configSection = 'debugger'
-    commandLineSwitch = ('D', 'debugger', 'Enter pdb on test fail or error')
-    # allow easy mocking and replacment of pdb
+
+    configSection = "debugger"
+    commandLineSwitch = ("D", "debugger", "Enter pdb on test fail or error")
+    # allow easy mocking and replacement of pdb
     pdb = pdb
 
     def __init__(self):
-        self.errorsOnly = self.config.as_bool('errors-only', default=False)
+        self.errorsOnly = self.config.as_bool("errors-only", default=False)
 
     def testOutcome(self, event):
         """Drop into pdb on unexpected errors or failures"""
