@@ -1,27 +1,27 @@
 """Common functionality."""
 import os.path
-import tempfile
+import platform
 import shutil
 import subprocess
 import sys
+import tempfile
+import unittest
 
-import six
-
-from nose2.compat import unittest
 from nose2 import discover, util
-
+from nose2._vendor import six
 
 HERE = os.path.abspath(os.path.dirname(__file__))
-SUPPORT = os.path.join(HERE, 'functional', 'support')
+SUPPORT = os.path.join(HERE, "functional", "support")
 
 
 class TestCase(unittest.TestCase):
 
     """TestCase extension.
 
-    If the class variable ``_RUN_IN_TEMP`` is ``True`` (default: ``False``), tests will be
-    performed in a temporary directory, which is deleted afterwards.
+    If the class variable ``_RUN_IN_TEMP`` is ``True`` (default: ``False``), tests will
+    be performed in a temporary directory, which is deleted afterwards.
     """
+
     _RUN_IN_TEMP = False
 
     def setUp(self):
@@ -69,7 +69,7 @@ class TestCase(unittest.TestCase):
 
 
 class FunctionalTestCase(unittest.TestCase):
-    tags = ['functional']
+    tags = ["functional"]
 
     def assertTestRunOutputMatches(self, proc, stdout=None, stderr=None):
         cmd_stdout, cmd_stderr = None, None
@@ -82,8 +82,13 @@ class FunctionalTestCase(unittest.TestCase):
         if cmd_stdout is None:
             cmd_stdout, cmd_stderr = proc.communicate()
             self._output[proc.pid] = cmd_stdout, cmd_stderr
-        testf = self.assertRegex if hasattr(self, 'assertRegex') \
+        # Python 2.7 needs this
+        # assertRegexpMatches() was renamed to assertRegex() in 3.2
+        testf = (
+            self.assertRegex
+            if hasattr(self, "assertRegex")
             else self.assertRegexpMatches
+        )
         if stdout:
             testf(util.safe_decode(cmd_stdout), stdout)
         if stderr:
@@ -98,11 +103,11 @@ class FunctionalTestCase(unittest.TestCase):
 
 class _FakeEventBase(object):
 
-    """Baseclass for fake :class:`~nose2.events.Event`\s."""
+    """Baseclass for fake :class:`~nose2.events.Event`s."""
 
     def __init__(self):
         self.handled = False
-        self.version = '0.1'
+        self.version = "0.1"
         self.metadata = {}
 
 
@@ -128,6 +133,7 @@ class FakeStartTestEvent(_FakeEventBase):
         self.test = test
         self.result = test.defaultTestResult()
         import time
+
         self.startTime = time.time()
 
 
@@ -153,8 +159,9 @@ class FakeStartTestRunEvent(_FakeEventBase):
 
     """Fake :class:`~nose2.events.StartTestRunEvent`"""
 
-    def __init__(self, runner=None, suite=None, result=None, startTime=None,
-                 executeTests=None):
+    def __init__(
+        self, runner=None, suite=None, result=None, startTime=None, executeTests=None
+    ):
         super(FakeStartTestRunEvent, self).__init__()
         self.suite = suite
         self.runner = runner
@@ -179,27 +186,30 @@ def support_file(*path_parts):
 
 
 def run_nose2(*nose2_args, **nose2_kwargs):
-    if 'cwd' in nose2_kwargs:
-        cwd = nose2_kwargs.pop('cwd')
+    if "cwd" in nose2_kwargs:
+        cwd = nose2_kwargs.pop("cwd")
         if not os.path.isabs(cwd):
-            nose2_kwargs['cwd'] = support_file(cwd)
+            nose2_kwargs["cwd"] = support_file(cwd)
     return NotReallyAProc(nose2_args, **nose2_kwargs)
 
 
 def run_module_as_main(test_module, *args):
     if not os.path.isabs(test_module):
         test_module = support_file(test_module)
-    return subprocess.Popen([sys.executable, test_module] + list(args),
-                            stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    return subprocess.Popen(
+        [sys.executable, test_module] + list(args),
+        stdout=subprocess.PIPE,
+        stderr=subprocess.PIPE,
+    )
 
 
 class NotReallyAProc(object):
-
     def __init__(self, args, cwd=None, **kwargs):
         self.args = args
         self.chdir = cwd
         self.kwargs = kwargs
         self.result = None
+        self._exit_code = None
 
     def __enter__(self):
         self._stdout = sys.__stdout__
@@ -222,10 +232,10 @@ class NotReallyAProc(object):
         with self:
             try:
                 self.result = discover(
-                    argv=('nose2',) + self.args, exit=False,
-                    **self.kwargs)
+                    argv=("nose2",) + self.args, exit=False, **self.kwargs
+                )
             except SystemExit as e:
-                pass
+                self._exit_code = e.code
             return self.stdout.getvalue(), self.stderr.getvalue()
 
     @property
@@ -234,8 +244,10 @@ class NotReallyAProc(object):
 
     def poll(self):
         if self.result is None:
-            return 1
-        return not self.result.result.wasSuccessful()
+            return self._exit_code if self._exit_code is not None else 1
+
+        # subprocess.poll should return None or the Integer exitcode
+        return int(not self.result.result.wasSuccessful())
 
 
 class RedirectStdStreams(object):
@@ -263,9 +275,8 @@ class RedirectStdStreams(object):
         sys.stderr = self.old_stderr
 
 
-# mock multprocessing Connection
+# mock multiprocessing Connection
 class Conn(object):
-
     def __init__(self, items):
         self.items = items
         self.sent = []
@@ -276,7 +287,7 @@ class Conn(object):
             raise EOFError("closed")
         try:
             return self.items.pop(0)
-        except:
+        except Exception:
             raise EOFError("EOF")
 
     def send(self, item):
@@ -284,3 +295,22 @@ class Conn(object):
 
     def close(self):
         self.closed = True
+
+
+# true on GitHub Actions, false otherwise
+def environment_is_ci():
+    return os.getenv("CI") == "true"
+
+
+# special skip decorator for tests which are broken in Windows in CI
+def windows_ci_skip(f):
+    return unittest.skipIf(
+        platform.system() == "Windows" and environment_is_ci(),
+        "This test is skipped on Windows in CI",
+    )(f)
+
+
+def _method_name(name="test"):
+    """Get an extra method name for Python 3.11"""
+    # https://github.com/python/cpython/issues/58473
+    return r"\." + name if sys.version_info >= (3, 11) else ""
