@@ -4,14 +4,13 @@ STATE = {}
 
 
 class Base(object):
-
     @classmethod
     def setUp(cls):
-        STATE['base'] = 'setup'
+        STATE["base"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['base']
+        del STATE["base"]
 
 
 class LayerA(Base):
@@ -19,21 +18,21 @@ class LayerA(Base):
 
     @classmethod
     def setUp(cls):
-        STATE['layerA'] = 'setup'
+        STATE["layerA"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerA']
+        del STATE["layerA"]
 
     @classmethod
     def testSetUp(cls, test):
-        STATE['layerA.test'] = 'setup'
+        STATE["layerA.test"] = "setup"
         # print "->", STATE, test
 
     @classmethod
     def testTearDown(cls, test):
         # print "<-", STATE, test
-        del STATE['layerA.test']
+        del STATE["layerA.test"]
 
 
 class LayerA_1(LayerA):
@@ -41,11 +40,11 @@ class LayerA_1(LayerA):
 
     @classmethod
     def setUp(cls):
-        STATE['layerA_1'] = 'setup'
+        STATE["layerA_1"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerA_1']
+        del STATE["layerA_1"]
 
 
 class LayerB(LayerA):
@@ -53,11 +52,11 @@ class LayerB(LayerA):
 
     @classmethod
     def setUp(cls):
-        STATE['layerB'] = 'setup'
+        STATE["layerB"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerB']
+        del STATE["layerB"]
 
 
 class LayerB_1(LayerB):
@@ -65,11 +64,11 @@ class LayerB_1(LayerB):
 
     @classmethod
     def setUp(cls):
-        STATE['layerB_1'] = 'setup'
+        STATE["layerB_1"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerB_1']
+        del STATE["layerB_1"]
 
 
 class LayerC(LayerB, LayerA):
@@ -77,11 +76,11 @@ class LayerC(LayerB, LayerA):
 
     @classmethod
     def setUp(cls):
-        STATE['layerC'] = 'setup'
+        STATE["layerC"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerC']
+        del STATE["layerC"]
 
 
 class LayerD(Base):
@@ -89,34 +88,36 @@ class LayerD(Base):
 
     @classmethod
     def setUp(cls):
-        STATE['layerD'] = 'setup'
+        STATE["layerD"] = "setup"
 
     @classmethod
     def tearDown(cls):
-        del STATE['layerD']
+        del STATE["layerD"]
 
 
 class Outer(unittest.TestCase):
     layer = Base
 
     def test(self):
-        self.assertEqual(STATE.get('base'), 'setup')
+        self.assertEqual(STATE.get("base"), "setup")
 
 
 class InnerA(unittest.TestCase):
     layer = LayerA
 
     def setUp(self):
-        STATE['innerA.test'] = 'setup'
+        STATE["innerA.test"] = "setup"
 
     def tearDown(self):
-        del STATE['innerA.test']
+        del STATE["innerA.test"]
 
     def test(self):
-        expect = {'base': 'setup',
-                  'layerA': 'setup',
-                  'innerA.test': 'setup',
-                  'layerA.test': 'setup'}
+        expect = {
+            "base": "setup",
+            "layerA": "setup",
+            "innerA.test": "setup",
+            "layerA.test": "setup",
+        }
         for k, v in expect.items():
             self.assertEqual(STATE.get(k), v)
 
@@ -125,10 +126,12 @@ class InnerA_1(unittest.TestCase):
     layer = LayerA_1
 
     def test(self):
-        expect = {'base': 'setup',
-                  'layerA': 'setup',
-                  'layerA_1': 'setup',
-                  'layerA.test': 'setup'}
+        expect = {
+            "base": "setup",
+            "layerA": "setup",
+            "layerA_1": "setup",
+            "layerA.test": "setup",
+        }
         for k, v in expect.items():
             self.assertEqual(STATE.get(k), v)
 
@@ -137,19 +140,17 @@ class InnerB(unittest.TestCase):
     layer = LayerB
 
     def setUp(self):
-        STATE['innerB.test'] = 'setup'
+        STATE["innerB.test"] = "setup"
 
     def tearDown(self):
-        STATE['innerB.test'] = 'tearDown'
+        STATE["innerB.test"] = "tearDown"
 
 
 class InnerB_1(unittest.TestCase):
     layer = LayerB_1
 
     def test(self):
-        expect = {'base': 'setup',
-                  'layerB': 'setup',
-                  'layerB_1': 'setup'}
+        expect = {"base": "setup", "layerB": "setup", "layerB_1": "setup"}
         for k, v in expect.items():
             self.assertEqual(STATE.get(k), v)
 
@@ -158,20 +159,24 @@ class InnerC(unittest.TestCase):
     layer = LayerC
 
     def test(self):
-        expect = {'base': 'setup',
-                  'layerB': 'setup',
-                  'layerC': 'setup',
-                  'layerA': 'setup',
-                  'layerA.test': 'setup'}
+        expect = {
+            "base": "setup",
+            "layerB": "setup",
+            "layerC": "setup",
+            "layerA": "setup",
+            "layerA.test": "setup",
+        }
         for k, v in expect.items():
             self.assertEqual(STATE.get(k), v)
 
     def test2(self):
-        expect = {'base': 'setup',
-                  'layerB': 'setup',
-                  'layerC': 'setup',
-                  'layerA': 'setup',
-                  'layerA.test': 'setup'}
+        expect = {
+            "base": "setup",
+            "layerB": "setup",
+            "layerC": "setup",
+            "layerA": "setup",
+            "layerA.test": "setup",
+        }
         for k, v in expect.items():
             self.assertEqual(STATE.get(k), v)
 
@@ -180,15 +185,10 @@ class InnerD(unittest.TestCase):
     layer = LayerD
 
     def test(self):
-        """test with docstring
-        """
-        self.assertEqual(
-            {'base': 'setup',
-             'layerD': 'setup'},
-            STATE)
+        """test with docstring"""
+        self.assertEqual({"base": "setup", "layerD": "setup"}, STATE)
 
 
 class NoLayer(unittest.TestCase):
-
     def test(self):
         self.assertEqual(STATE, {})
