@@ -12,25 +12,25 @@ class Layer1(object):
     @classmethod
     def setUp(cls):
         if cls.layer_setup >= 1:
-            raise Exception('layer_setup already ran')
+            raise Exception("layer_setup already ran")
         cls.layer_setup += 1
 
     @classmethod
     def testSetUp(cls):
         if cls.test_setup >= 2:
-            raise Exception('test_setup already ran twice')
+            raise Exception("test_setup already ran twice")
         cls.test_setup += 1
 
     @classmethod
     def testTearDown(cls):
         if cls.test_teardown >= 2:
-            raise Exception('test_teardown already ran twice')
+            raise Exception("test_teardown already ran twice")
         cls.test_teardown += 1
 
     @classmethod
     def tearDown(cls):
         if cls.layer_teardown >= 1:
-            raise Exception('layer_teardown already ran')
+            raise Exception("layer_teardown already ran")
         cls.layer_teardown += 1
 
 
