@@ -1,14 +1,14 @@
 import unittest
 
-class Layer(object):
 
+class Layer(object):
     @classmethod
     def setUp(cls):
-        raise RuntimeError('Bad Error in Layer setUp!')
+        raise RuntimeError("Bad Error in Layer setUp!")
 
 
 class Test(unittest.TestCase):
     layer = Layer
-    
+
     def testPass(self):
         pass
