@@ -1,17 +1,18 @@
 import unittest
 
-class Layer(object):
 
+class Layer(object):
     @classmethod
     def setUp(cls):
         pass
 
     @classmethod
     def testTearDown(cls):
-        raise RuntimeError('Bad Error in Layer testTearDown!')
+        raise RuntimeError("Bad Error in Layer testTearDown!")
+
 
 class Test(unittest.TestCase):
     layer = Layer
-    
+
     def testPass(self):
         pass
