@@ -1,4 +1,5 @@
 import time
+
 from nose2.tools import such
 
 
@@ -30,21 +31,21 @@ class Layer2(object):
         it.obj = slow_blocking_init()
 
 
-with such.A('system with a fast initial setup layer') as it:
+with such.A("system with a fast initial setup layer") as it:
 
     it.uses(Layer1)
 
-    @it.should('not have obj initialized')
+    @it.should("not have obj initialized")
     def test():
         assert not it.obj
 
-
-    with it.having('a second slow setup layer'):
+    with it.having("a second slow setup layer"):
 
         it.uses(Layer2)
 
-        @it.should('have obj initialized')
-        def test():
+        @it.should("have obj initialized")
+        def test2():
             assert it.obj
 
+
 it.createTests(globals())
